@@ -1,7 +1,7 @@
 package HTML::FormFu::Constraint;
 
 use strict;
-our $VERSION = '2.03'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose;
 use MooseX::Attribute::FormFuChained;
@@ -14,11 +14,8 @@ use HTML::FormFu::Util qw(
     debug
 );
 use Clone ();
-use List::MoreUtils qw( any );
-use Scalar::Util qw( blessed );
 use Carp qw( croak );
-use List::MoreUtils qw( any all );
-use List::Util qw( first );
+use List::Util 1.33 qw( any all first );
 use Scalar::Util qw( reftype blessed );
 
 has not          => ( is => 'rw', traits => ['FormFuChained'] );
@@ -216,8 +213,8 @@ sub mk_error {
 sub _process_when {
     my ( $self, $params ) = @_;
 
-    # returns 1 if when condition is fullfilled or not defined
-    # returns 0 if when condition is defined and not fullfilled
+    # returns 1 if when condition is fulfilled or not defined
+    # returns 0 if when condition is defined and not fulfilled
     # If it's a callback, return callback's return value (so 'when'
     # condition is met if callback returns a true value)
 
@@ -355,7 +352,7 @@ HTML::FormFu::Constraint - Constrain User Input
 
 =head1 VERSION
 
-version 2.03
+version 2.05
 
 =head1 SYNOPSIS
 
@@ -481,7 +478,7 @@ Shorthand for C<< $constraint->parent->name >>
 
 =head2 when
 
-Defines a condition for the constraint. Only when the condition is fullfilled
+Defines a condition for the constraint. Only when the condition is fulfilled
 the constraint will be applied.
 
 This method expects a hashref.
@@ -497,7 +494,7 @@ The following keys are supported:
 
 =item field
 
-Nested-name of form field that shall be checked against - if C<when->{value}>
+Nested-name of form field that shall be checked against - if C<< when->{value} >>
 is set, the C<when> condition passes if the named field's value matches that,
 otherwise the C<when> condition passes if the named field's value is true.
 
@@ -517,7 +514,7 @@ Expected value in the form field 'field'
 
 =item values
 
-Array of multiple values, one must match to fullfill the condition
+Array of multiple values, one must match to fulfill the condition
 
 =item not
 
@@ -527,7 +524,7 @@ Inverts the when condition - value(s) must not match
 
 A callback subroutine-reference or fully resolved subroutine name can be
 supplied to perform complex checks. An hashref of all parameters is passed
-to the callback sub. In this case all other keys are ignored, including not.
+to the callback sub. In this case all other keys are ignored, including C<not>.
 You need to return a true value for the constraint to be applied or a false
 value to not apply it.
 
