@@ -1,7 +1,7 @@
 package HTML::FormFu::Constraint::Equal;
 
 use strict;
-our $VERSION = '2.03'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose;
 extends 'HTML::FormFu::Constraint';
@@ -12,7 +12,7 @@ use HTML::FormFu::Util qw(
     DEBUG_CONSTRAINTS
     debug
 );
-use List::MoreUtils qw( all );
+use List::Util 1.33 qw( all );
 
 our $EMPTY_STR = q{};
 
@@ -124,7 +124,7 @@ HTML::FormFu::Constraint::Equal - Multi-field Equality Constraint
 
 =head1 VERSION
 
-version 2.03
+version 2.05
 
 =head1 SYNOPSIS
 
