@@ -1,13 +1,13 @@
 package HTML::FormFu::Constraint::File::MIME;
 
 use strict;
-our $VERSION = '2.02'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Constraint';
 
-use List::MoreUtils qw( any );
+use List::Util 1.33 qw( any );
 use Scalar::Util qw( blessed );
 
 has regex => ( is => 'rw', traits => ['FormFuChained'] );
@@ -51,7 +51,7 @@ HTML::FormFu::Constraint::File::MIME - MIME Type Constraint
 
 =head1 VERSION
 
-version 2.02
+version 2.05
 
 =head1 DESCRIPTION
 
