@@ -1,7 +1,7 @@
 package HTML::FormFu::Deflator::CompoundDateTime;
 
 use strict;
-our $VERSION = '2.03'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose;
 use MooseX::Attribute::FormFuChained;
@@ -9,7 +9,7 @@ extends 'HTML::FormFu::Deflator';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 use DateTime;
-use List::MoreUtils qw( none );
+use List::Util 1.33 qw( none );
 use Carp qw( croak );
 
 has field_order => ( is => 'rw', traits => ['FormFuChained'] );
@@ -65,7 +65,7 @@ HTML::FormFu::Deflator::CompoundDateTime - CompoundDateTime deflator
 
 =head1 VERSION
 
-version 2.03
+version 2.05
 
 =head1 SYNOPSIS
 
