@@ -3,7 +3,7 @@ package HTML::FormFu::Deploy;
 use strict;
 use warnings;
 
-our $VERSION = '2.03'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 use Cwd qw( getcwd );
@@ -17,7 +17,9 @@ use Carp qw( croak );
 our $SHARE_DIR;
 
 if ( -f 'MANIFEST.SKIP' && -d 'share/templates/tt/xhtml' ) {
-    warn "Running as a developer, using the local, not installed templates\n\n";
+    warn
+        "Running as a developer, using the local, not installed templates\n\n"
+        unless ( $ENV{HARNESS_ACTIVE} );
 
     my $cwd = getcwd();
 
