@@ -1,7 +1,7 @@
 package HTML::FormFu::Element::Block;
 
 use strict;
-our $VERSION = '2.03'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose;
 use MooseX::Attribute::FormFuChained;
@@ -18,7 +18,7 @@ with 'HTML::FormFu::Role::CreateChildren',
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 use HTML::FormFu::Util qw( _get_elements xml_escape process_attrs );
 use Clone ();
-use List::MoreUtils qw( uniq );
+use List::Util 1.45 qw( uniq );
 use Carp qw( croak );
 
 has tag                  => ( is => 'rw', traits => ['FormFuChained'] );
@@ -269,7 +269,7 @@ HTML::FormFu::Element::Block - Block element
 
 =head1 VERSION
 
-version 2.03
+version 2.05
 
 =head1 SYNOPSIS
 
