@@ -1,7 +1,7 @@
 package HTML::FormFu::Element::Checkboxgroup;
 
 use strict;
-our $VERSION = '2.03'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose;
 use MooseX::Attribute::FormFuChained;
@@ -11,7 +11,7 @@ with 'HTML::FormFu::Role::Element::Group';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 use HTML::FormFu::Util qw( append_xml_attribute process_attrs );
-use List::MoreUtils qw( any );
+use List::Util 1.33 qw( any );
 
 has input_type => (
     is      => 'rw',
@@ -245,7 +245,7 @@ HTML::FormFu::Element::Checkboxgroup - Group of checkbox form fields
 
 =head1 VERSION
 
-version 2.03
+version 2.05
 
 =head1 SYNOPSIS
 
