@@ -1,7 +1,7 @@
 package HTML::FormFu::Element::ComboBox;
 
 use strict;
-our $VERSION = '2.03'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose;
 use MooseX::Attribute::FormFuChained;
@@ -10,7 +10,7 @@ extends 'HTML::FormFu::Element::Multi';
 with 'HTML::FormFu::Role::Element::ProcessOptionsFromModel';
 
 use HTML::FormFu::Util qw( _filter_components _parse_args );
-use List::MoreUtils qw( any );
+use List::Util 1.33 qw( any );
 use Moose::Util qw( apply_all_roles );
 
 our @DEFER_TO_SELECT = qw(
@@ -298,7 +298,7 @@ HTML::FormFu::Element::ComboBox - Select / Text hybrid
 
 =head1 VERSION
 
-version 2.03
+version 2.05
 
 =head1 SYNOPSIS
 
