@@ -1,7 +1,7 @@
 package HTML::FormFu::Element::Label;
 
 use strict;
-our $VERSION = '2.02'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose;
 use MooseX::Attribute::FormFuChained;
@@ -13,7 +13,7 @@ with 'HTML::FormFu::Role::Element::Field',
     'HTML::FormFu::Role::Element::Coercible';
 
 use HTML::FormFu::Util qw( process_attrs );
-use List::MoreUtils qw( none );
+use List::Util 1.33 qw( none );
 
 has field_type => ( is => 'rw', traits => ['FormFuChained'] );
 
@@ -98,7 +98,7 @@ HTML::FormFu::Element::Label - field for displaying only
 
 =head1 VERSION
 
-version 2.02
+version 2.05
 
 =head1 DESCRIPTION
 
