@@ -1,7 +1,7 @@
 package HTML::FormFu::Element::Select;
 
 use strict;
-our $VERSION = '2.03'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose;
 extends 'HTML::FormFu::Element';
@@ -10,7 +10,7 @@ with 'HTML::FormFu::Role::Element::Group';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 use HTML::FormFu::Util qw( append_xml_attribute process_attrs );
-use List::MoreUtils qw( any );
+use List::Util 1.33 qw( any );
 
 __PACKAGE__->mk_attr_accessors(qw( multiple size ));
 
@@ -111,7 +111,7 @@ HTML::FormFu::Element::Select - Select form field
 
 =head1 VERSION
 
-version 2.03
+version 2.05
 
 =head1 SYNOPSIS
 
