@@ -1,7 +1,7 @@
 package HTML::FormFu::Inflator::CompoundDateTime;
 
 use strict;
-our $VERSION = '2.03'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose;
 use MooseX::Attribute::FormFuChained;
@@ -10,7 +10,7 @@ extends 'HTML::FormFu::Inflator';
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 use DateTime;
 use DateTime::Format::Strptime;
-use List::MoreUtils qw( none );
+use List::Util 1.33 qw( none );
 use Scalar::Util qw( reftype );
 use Carp qw( croak );
 
@@ -84,7 +84,7 @@ HTML::FormFu::Inflator::CompoundDateTime - CompoundDateTime inflator
 
 =head1 VERSION
 
-version 2.03
+version 2.05
 
 =head1 SYNOPSIS
 
