@@ -3,10 +3,10 @@ package HTML::FormFu::Localize;
 use strict;
 use warnings;
 
-our $VERSION = '2.02'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use HTML::FormFu::Util qw( require_class );
-use List::MoreUtils qw( any );
+use List::Util 1.33 qw( any );
 use List::MoreUtils qw( pairwise );
 use Scalar::Util qw( weaken isweak blessed );
 use Exporter qw( import );
