@@ -1,7 +1,7 @@
 package HTML::FormFu::OutputProcessor::StripWhitespace;
 
 use strict;
-our $VERSION = '2.02'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose;
 use MooseX::Attribute::FormFuChained;
@@ -9,7 +9,7 @@ extends 'HTML::FormFu::OutputProcessor';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 use HTML::TokeParser::Simple;
-use List::MoreUtils qw( any );
+use List::Util 1.33 qw( any );
 
 has collapse_tags => (
     is      => 'rw',
@@ -125,7 +125,7 @@ __PACKAGE__->meta->make_immutable;
 package HTML::FormFu::OutputProcessor::StripWhitespace::_iter;
 
 use strict;
-our $VERSION = '2.02'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose;
 use MooseX::Attribute::FormFuChained;
@@ -176,7 +176,7 @@ HTML::FormFu::OutputProcessor::StripWhitespace - Strip shitespace from HTML outp
 
 =head1 VERSION
 
-version 2.02
+version 2.05
 
 =head1 SYNOPSIS
 
