@@ -1,7 +1,7 @@
 package HTML::FormFu::Role::Constraint::Others;
 
 use strict;
-our $VERSION = '2.03'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose::Role;
 use MooseX::Attribute::FormFuChained;
@@ -11,7 +11,7 @@ use HTML::FormFu::Util qw(
     debug
 );
 use Clone ();
-use List::MoreUtils qw( any none );
+use List::Util 1.33 qw( any none );
 
 has others                  => ( is => 'rw', traits => ['FormFuChained'] );
 has other_siblings          => ( is => 'rw', traits => ['FormFuChained'] );
@@ -217,7 +217,7 @@ HTML::FormFu::Role::Constraint::Others - Base class for constraints needing othe
 
 =head1 VERSION
 
-version 2.03
+version 2.05
 
 =head1 METHODS
 
