@@ -1,7 +1,7 @@
 package HTML::FormFu::Role::ContainsElementsSharedWithField;
 
 use strict;
-our $VERSION = '2.03'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose::Role;
 
@@ -10,8 +10,6 @@ use HTML::FormFu::Util qw(
     _merge_hashes
 );
 use Carp qw( croak );
-use List::MoreUtils qw( none uniq );
-use Scalar::Util qw( refaddr weaken );
 
 sub get_error {
     my $self = shift;
