@@ -1,14 +1,14 @@
 package HTML::FormFu::Role::CreateChildren;
 
 use strict;
-our $VERSION = '2.03'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose::Role;
 
 use HTML::FormFu::Util qw( _merge_hashes require_class );
 use Carp qw( croak );
 use Clone ();
-use List::MoreUtils qw( uniq );
+use List::Util 1.45 qw( uniq );
 use Scalar::Util qw( weaken );
 
 sub element {
