@@ -1,7 +1,7 @@
 package HTML::FormFu::Role::Element::Field;
 
 use strict;
-our $VERSION = '2.03'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose::Role;
 use MooseX::Aliases;
@@ -24,7 +24,7 @@ use HTML::FormFu::Util qw(
 );
 use Class::MOP::Method;
 use Clone ();
-use List::MoreUtils qw( uniq );
+use List::Util 1.45 qw( uniq );
 use Carp qw( croak carp );
 
 __PACKAGE__->mk_attrs( qw(
@@ -1143,7 +1143,7 @@ HTML::FormFu::Role::Element::Field - Role for all form-field elements
 
 =head1 VERSION
 
-version 2.03
+version 2.05
 
 =head1 DESCRIPTION
 
