@@ -1,7 +1,7 @@
 package HTML::FormFu::Role::Element::Group;
 
 use strict;
-our $VERSION = '2.03'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose::Role;
 use MooseX::Attribute::FormFuChained;
@@ -14,7 +14,7 @@ with 'HTML::FormFu::Role::Element::Field',
 use HTML::FormFu::Attribute qw( mk_output_accessors );
 use HTML::FormFu::Util qw( append_xml_attribute literal xml_escape );
 use Clone ();
-use List::MoreUtils qw( none );
+use List::Util 1.33 qw( none );
 use Scalar::Util qw( reftype );
 use Carp qw( croak );
 
@@ -395,7 +395,7 @@ HTML::FormFu::Role::Element::Group - Role for grouped form fields
 
 =head1 VERSION
 
-version 2.03
+version 2.05
 
 =head1 DESCRIPTION
 
