@@ -1,13 +1,13 @@
 package HTML::FormFu::Role::FormAndBlockMethods;
 
 use strict;
-our $VERSION = '2.02'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose::Role;
 
 use HTML::FormFu::Util qw( _merge_hashes );
 use Carp qw( croak );
-use List::MoreUtils qw( none );
+use List::Util 1.33 qw( none );
 
 sub default_args {
     my ( $self, $defaults ) = @_;
