@@ -1,7 +1,7 @@
 package HTML::FormFu::Validator::Callback;
 
 use strict;
-our $VERSION = '2.02'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 use Moose;
 use MooseX::Attribute::FormFuChained;
@@ -10,14 +10,14 @@ extends 'HTML::FormFu::Validator';
 has callback => ( is => 'rw', traits => ['FormFuChained'] );
 
 sub validate_value {
-    my ( $self, $value ) = @_;
+    my ( $self, $value, $params ) = @_;
 
     my $callback = $self->callback || sub {1};
 
     ## no critic (ProhibitNoStrict);
     no strict 'refs';
 
-    my $ok = $callback->($value);
+    my $ok = $callback->($value, $params);
 
     return $ok;
 }
@@ -34,7 +34,7 @@ HTML::FormFu::Validator::Callback - Callback validator
 
 =head1 VERSION
 
-version 2.02
+version 2.05
 
 =head1 SYNOPSIS
 
@@ -52,6 +52,10 @@ version 2.02
 
 Callback validator.
 
+The first argument passed to the callback is the submitted value for the
+associated field. The second argument passed to the callback is a hashref of
+name/value pairs for all input fields.
+
 =head1 METHODS
 
 =head2 callback
