@@ -1,10 +1,10 @@
 package HTMLFormFu::DBICUniqueFake;
-
 use Moose;
+use MooseX::Attribute::FormFuChained;
 
 extends 'HTML::FormFu::Constraint';
 
-has id_field       => ( is => 'rw', traits  => ['Chained'] );
+has id_field => ( is => 'rw', traits => ['FormFuChained'] );
 
 sub constrain_value {
     my ( $self, $value ) = @_;
