@@ -1,35 +1,33 @@
-package 
-    HTMLFormFu::TestLib;
+package HTMLFormFu::TestLib;
 
 use strict;
 use warnings;
 
 sub mock_query {
     my ( $self, $query ) = @_;
-    
-    return HTMLFormFu::MockObject->new( $query );
+
+    return HTMLFormFu::MockObject->new($query);
 }
 
 ####
 
-package 
-    HTMLFormFu::MockObject;
+package HTMLFormFu::MockObject;
 
 use strict;
 use warnings;
 
 sub new {
     my ( $class, $query ) = @_;
-    
+
     die "query must be a hashref"
         unless ref($query) eq 'HASH';
-    
+
     return bless $query, $class;
 }
 
 sub param {
     my ( $self, $param, $value ) = @_;
-    
+
     if ( @_ == 1 ) {
         return keys %$self;
     }
@@ -43,15 +41,15 @@ sub param {
         }
         if ( ref $self->{$param} eq 'ARRAY' ) {
             return (wantarray)
-              ? @{ $self->{$param} }
-              : $self->{$param}->[0];
+                ? @{ $self->{$param} }
+                : $self->{$param}->[0];
         }
         else {
             return (wantarray)
-              ? ( $self->{$param} )
-              : $self->{$param};
+                ? ( $self->{$param} )
+                : $self->{$param};
         }
     }
-} 
+}
 
 1;
